# -*- coding: utf-8 -*-

def multiplication(a,b):
	return a*b

if __name__ == '__main__':
	pass